@@ -22,7 +22,7 @@ class COINNLocal:
     _PROMPT_MODE_ = f"Mode must be provided and should be one of {[Mode.TRAIN, Mode.TEST]}."
 
     def __init__(self, cache: dict = None, input: dict = None, state: dict = None,
-                 task_name=None,
+                 computation_id=None,
                  mode: str = None,
                  batch_size: int = 4,
                  epochs: int = 21,
@@ -30,7 +30,7 @@ class COINNLocal:
                  gpus: _List[int] = None,
                  pin_memory: bool = _conf.gpu_available,
                  num_workers: int = 0,
-                 load_limit: int = float('inf'),
+                 load_limit: int = _conf.data_load_lim,
                  pretrained_path: str = None,
                  patience: int = 5,
                  load_sparse: bool = False,
@@ -43,7 +43,7 @@ class COINNLocal:
         self.state = _FrozenDict(state)
         self.data_splitter = data_splitter
         self.args = {}
-        self.args['task_name'] = task_name  # test/train
+        self.args['computation_id'] = computation_id  #
         self.args['mode'] = mode  # test/train
         self.args['batch_size'] = batch_size
         self.args['epochs'] = epochs
@@ -58,11 +58,11 @@ class COINNLocal:
         self.args['num_folds'] = num_folds
         self.args['split_ratio'] = split_ratio
         self.args.update(**kw)
-        self._check_args()
+        self.args = _FrozenDict(self.args)
 
     def _check_args(self):
-        assert self.cache['task_name'] is not None, self._PROMPT_TASK_
-        assert self.cache['mode'] in [Mode.TRAIN, Mode.TEST], self._PROMPT_TASK_
+        assert self.cache['computation_id'] is not None, self._PROMPT_TASK_
+        assert self.cache['mode'] in [Mode.TRAIN, Mode.TEST], self._PROMPT_MODE_
 
     def compute(self, dataset_cls, trainer_cls):
         trainer = trainer_cls(cache=self.cache, input=self.input, state=self.state)
@@ -78,6 +78,7 @@ class COINNLocal:
             self.out.update(_du.init_k_folds(self.cache, self.state, self.data_splitter))
             self.cache['args'] = _FrozenDict(self.cache)
             self.out['mode'] = self.cache['mode']
+            self._check_args()
 
         if nxt_phase == Phase.INIT_NN:
             """  Initialize neural network/optimizer and GPUs  """
@@ -85,13 +86,13 @@ class COINNLocal:
             self.cache.update(**self.input['run'][self.state['clientId']], epoch=0, cursor=0, train_log=[])
             self.cache['split_file'] = self.cache['splits'][str(self.cache['split_ix'])]
             self.cache['log_dir'] = self.state['outputDirectory'] + _sep + self.cache[
-                'task_name'] + _sep + f"fold_{self.cache['split_ix']}"
+                'computation_id'] + _sep + f"fold_{self.cache['split_ix']}"
             _os.makedirs(self.cache['log_dir'], exist_ok=True)
 
             trainer.init_nn(init_weights=True)
             self.cache['current_nn_state'] = 'current.nn.pt'
             self.cache['best_nn_state'] = 'best.nn.pt'
-            trainer.save_checkpoint(name=self.cache['current_nn_state'])
+            trainer.save_checkpoint(file_name=self.cache['current_nn_state'])
             trainer.load_data_indices(dataset_cls, split_key='train')
             nxt_phase = Phase.COMPUTATION
 
@@ -133,7 +134,7 @@ class COINNLocal:
         elif nxt_phase == Phase.SUCCESS:
             """ This phase receives global scores from the aggregator."""
             _shutil.copy(f"{self.state['baseDirectory']}{_sep}{self.input['results_zip']}.zip",
-                         f"{self.state['outputDirectory'] + _sep + self.cache['task_name']}{_sep}{self.input['results_zip']}.zip")
+                         f"{self.state['outputDirectory'] + _sep + self.cache['computation_id']}{_sep}{self.input['results_zip']}.zip")
 
         self.out['phase'] = nxt_phase
 
